@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## DateTime Format Relative Time - ~/lib/DateTime/Format/RelativeTime.pm
-## Version v0.1.2
+## Version v0.1.3
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2024/12/30
@@ -27,7 +27,7 @@ BEGIN
     use Locale::Unicode::Data v1.3.0;
     use Scalar::Util ();
     use Want;
-    our $VERSION = 'v0.1.2';
+    our $VERSION = 'v0.1.3';
 };
 
 use strict;
@@ -50,21 +50,18 @@ sub new
     # Test for the locale data availability
     LOCALE_AVAILABILITY: foreach my $loc ( @$test_locales )
     {
-        $self->_message( 4, "Checking if requested locale '${loc}' is supported." );
         my $tree = $cldr->make_inheritance_tree( $loc ) ||
             return( $self->pass_error( $cldr->error ) );
         # We remove the last 'und' special fallback locale
         pop( @$tree );
         foreach my $l ( @$tree )
         {
-            $self->_message( 4, "Checking if locale '${l}' is supported by time relative." );
             my $all = $cldr->time_relatives_l10n(
                 locale => $l,
             );
             return( $self->pass_error( $cldr->error ) ) if( !defined( $all ) && $cldr->error );
             if( $all && scalar( @$all ) )
             {
-                $self->_message( 4, "Found time format data for locale '${l}' (originally '${loc}')" );
                 if( Scalar::Util::blessed( $loc ) && ref( $loc ) eq 'Locale::Intl' )
                 {
                     $locale = $loc;
@@ -80,14 +77,12 @@ sub new
     }
     # Choice of locales provided do not have a supported match, so we fall back to the default 'en'
     $locale = Locale::Intl->new( 'en' ) if( !defined( $locale ) );
-    $self->_message( 4, "Eventually the locale we will use is '${locale}'" );
     $self->{locale} = $locale;
     my $unicode = $self->{_unicode} = DateTime::Locale::FromCLDR->new( $locale ) ||
         return( $self->pass_error( DateTime::Locale::FromCLDR->error ) );
 
     my @component_options = qw( numberingSystem style numeric );
     my @core_options = grep{ exists( $opts->{ $_ } ) } @component_options;
-    $self->_message( 4, "Checking the sanity of the options provided: ", sub{ dump( $opts ) } );
     # RangeError: invalid value "plop" for option month
     my %valid_options = 
     (
@@ -99,10 +94,8 @@ sub new
     
     foreach my $key ( keys( %$opts ) )
     {
-        $self->_message( 4, "Checking option '${key}' with value '", $opts->{ $key }, "'" );
         unless( exists( $valid_options{ $key } ) )
         {
-            $self->_message( 4, "'${key}' is an unsupported option." );
             return( $self->error({
                 type => 'RangeError',
                 message => "Invalid option \"${key}\"",
@@ -111,10 +104,8 @@ sub new
         my $value = $opts->{ $key };
         if( ref( $valid_options{ $key} ) eq 'ARRAY' )
         {
-            $self->_message( 4, "Checking the option '${key}' value '${value}' against all possible values: '", join( "', '", map( ( $_ // 'undef' ), @{$valid_options{ $key }} ) ), "'" );
             if( !scalar( grep { ( $_ // '' ) eq ( $value // '' ) } @{$valid_options{ $key }} ) )
             {
-                $self->_message( 4, "The option '${key}' value '${value}' is unsupported." );
                 return( $self->error({
                     type => 'RangeError',
                     message => "Invalid value \"${value}\" for option ${key}. Expected one of: " . @{$valid_options{ $key }},
@@ -123,10 +114,8 @@ sub new
         }
         elsif( ref( $valid_options{ $key} ) eq 'Regexp' )
         {
-            $self->_message( 4, "Checking the option '${key}' value '${value}' against the regular expresion '", $valid_options{ $key}, "'" );
             if( $value !~ /^$valid_options{ $key}$/ )
             {
-                $self->_message( 4, "The option '${key}' value '${value}' does not match the regular expression '", $valid_options{ $key}, "'" );
                 return( $self->error({
                     type => 'RangeError',
                     message => "Invalid value \"${value}\" for option ${key}.",
@@ -141,24 +130,19 @@ sub new
     };
     @$resolved{ @core_options } = @$opts{ @core_options };
     my $num_sys = $opts->{numberingSystem};
-    $self->_message( 4, "Checking the options values provided and building the resolvedOptions hash." );
 
     my $systems = $unicode->number_systems;
     my $ns_default = $unicode->number_system;
     # To contain the locale's number system's digits
     my $ns_digits;
-    $self->_message( 4, "Number systems for locale '${locale}' is: ", sub{ dump( $systems ) } );
     my $ns_default_def = $cldr->number_system( number_system => $ns_default ) ||
         return( $self->pass_error( $cldr->error ) );
-    $self->_message( 4, "Default number system for locale '${locale}' is: ", sub{ dump( $ns_default ) }, ", and has the following definition: ", sub{ dump( $ns_default_def ) } );
     undef( $ns_default ) unless( $ns_default_def->{type} eq 'numeric' );
     # NOTE: number system check
     # The user has provided a number system as the option 'numberingSystem', let's check it
     if( $num_sys )
     {
-        $self->_message( 4, "A numbering system '${num_sys}' was provided, checking if it is valid." );
         my $num_sys_def = $cldr->number_system( number_system => $num_sys );
-        $self->_message( 4, "Numbering system provided (${num_sys}) has the following information: ", sub{ dump( $num_sys_def ) } );
         return( $self->pass_error( $cldr->error ) ) if( !defined( $num_sys_def ) && $cldr->error );
         if( $num_sys_def && scalar( keys( %$num_sys_def ) ) )
         {
@@ -196,12 +180,9 @@ sub new
         my $num_sys_def = $cldr->number_system( number_system => $locale_num_sys );
         return( $self->pass_error( $cldr->error ) ) if( !defined( $num_sys_def ) && $cldr->error );
         $num_sys_def ||= {};
-        $self->_message( 4, "The locale '${locale}' has an extension 'nu' with value '${locale_num_sys}', checking it." );
-        $self->_message( 4, "Locale numbering system provided (${locale_num_sys}) has the following information: ", sub{ dump( $num_sys_def ) } );
         if( $locale_num_sys eq 'latn' || ( scalar( grep( ( $systems->{ $_ } // '' ) eq $locale_num_sys, qw( number_system native ) ) ) && $num_sys_def->{type} ne 'numeric' ) )
         {
             $num_sys = $locale_num_sys;
-            $self->_message( 4, "Locale 'nu' extension value '${num_sys}' looks valid." );
         }
         else
         {
@@ -213,22 +194,18 @@ sub new
     # If the locale already has a country code / region associated, it is specific enough
     if( !defined( $num_sys ) && !( my $cc = $locale->country_code ) )
     {
-        $self->_message( 4, "Country code for locale '${locale}' does not exist, using likely locale to get the country code, and get a more specific locale for the numbering system." );
         my $tree = $cldr->make_inheritance_tree( $locale ) ||
             return( $self->pass_error( $cldr->error ) );
         LOCALE: foreach my $loc ( @$tree )
         {
-            $self->_message( 4, "Trying to expand locale '${locale}' using '${loc}'" );
             my $ref = $cldr->likely_subtag( locale => $loc );
             # Ok, we found an expanded locale, now let's get its number system
             if( $ref && $ref->{target} )
             {
-                $self->_message( 4, "Ok, we found an entry for expanded locale '${loc}': ", sub{ dump( $ref ) } );
                 my $expanded_locale = Locale::Unicode->new( $ref->{target} ) ||
                     return( $self->pass_error( Locale::Unicode->error ) );
                 # Get the locale number systems
                 my $expanded_locale_tree = $cldr->make_inheritance_tree( $expanded_locale );
-                $self->_message( 4, "Checking for numbering system in the expanded locale inheritance tree @$expanded_locale_tree" );
                 return( $self->pass_error( $cldr->error ) ) if( !defined( $expanded_locale_tree ) && $cldr->error );
 
                 my $locale_ns_def;
@@ -244,12 +221,10 @@ sub new
                 }
                 return( $self->error( "Unable to find any numbering system for any locale in the inheritance tree @$expanded_locale_tree" ) ) if( !defined( $locale_ns_def ) );
 
-                $self->_message( 4, "The expanded locale '${expanded_locale}' has the following numbering system, checking each possible value: ", sub{ dump( $locale_ns_def ) } );
                 foreach my $ns_type ( qw( number_system native traditional finance ) )
                 {
                     # It may not be defined for that locale, and in this case, we skip to the next one.
                     next if( !length( $locale_ns_def->{ $ns_type } // '' ) );
-                    $self->_message( 4, "Checking numbering system definition for '", $locale_ns_def->{ $ns_type }, "'" );
                     my $ns_def = $cldr->number_system( number_system => $locale_ns_def->{ $ns_type } );
                     return( $self->pass_error( $cldr->error ) ) if( !defined( $ns_def ) && $cldr->error );
                     # It needs to be 'numeric', as opposed to 'algorithmic', or else we cannot use it
@@ -258,7 +233,6 @@ sub new
                         ref( $ns_def->{digits} ) eq 'ARRAY' &&
                         scalar( @{$ns_def->{digits}} ) )
                     {
-                        $self->_message( 4, "Found a match for the numbering system '", $locale_ns_def->{ $ns_type }, "'" );
                         $ns_digits = $ns_def->{digits};
                         $num_sys = $locale_ns_def->{ $ns_type };
                         last LOCALE;
@@ -271,7 +245,6 @@ sub new
     # Still have not found anything
     if( !length( $num_sys // '' ) )
     {
-        $self->_message( 4, "No numbering system found so far, falling back on the locale's preferred one '", ( ( $systems->{number_system} || $systems->{native} || $systems->{traditional} ) // 'undef' ), "' or 'latn' in last resort." );
         $num_sys //= $ns_default || 'latn';
     }
     $resolved->{numberingSystem} = $num_sys;
@@ -287,7 +260,6 @@ sub new
     }
 
     $self->{resolvedOptions} = $resolved;
-    $self->_message( 4, "resolvedOptions hash is: ", sub{ dump( $resolved ) } );
     unless( defined( $ns_digits ) )
     {
         my $ns_def = $cldr->number_system( number_system => $num_sys );
@@ -302,7 +274,6 @@ sub new
         $ns_digits = $ns_def->{digits};
     }
     $self->{_ns_digits} = $ns_digits;
-    $self->_message( 4, "Decimals for the numbering system '${num_sys}' are: ", sub{ dump( $ns_digits ) } );
     return( $self );
 }
 
@@ -350,7 +321,6 @@ sub format
     }
 
     my $str = join( '', map( $_->{value}, @$parts ) );
-    $self->_message( 4, "Done, returning combined string: '", ( $str // 'undef' ), "'" );
     return( $str );
 }
 
@@ -440,7 +410,6 @@ sub format_to_parts
         # $num could be 0.0, and this edge case would disrupt formatting, so we need to transform it to a simple 0
         # Using sprintf also ensures .5 becomes 0.5, or -.5 becomes -0.5
         $num = sprintf( '%.15g', $num );
-        $self->_message( 4, "After possible adjustments, the provided number ends up being '${num}'" );
     }
     else
     {
@@ -450,7 +419,6 @@ sub format_to_parts
         }) );
     }
     my $opts = $self->resolvedOptions;
-    $self->_message( 4, "Formatting relative time for integer '${num}', and unit '${unit}' and resolved options: ", sub{ dump( $opts ) } );
     my $pattern;
     my $algo = lc( $opts->{numeric} || 'always' );
     my $style = lc( $opts->{style} || 'long' );
@@ -462,25 +430,21 @@ sub format_to_parts
         return( $self->pass_error( $cldr->error ) );
     # We set an array of possible styles to try to find the most appropriate, while putting the user preferred one first
     my @styles = ( $cldr_style, ( grep{ $_ ne $style } qw( long short narrow ) ) );
-    $self->_message( 4, "Trying to get the locale relative time pattern using inheritance tree: ", sub{ dump( $tree ) } );
     # If the algorithm is set to auto, we check if we can find a relative value -1, 0 or 1 for our unit type
     # If not, we fall back to the numeric pattern
     if( $algo eq 'auto' && 
         ( $num >= -1 && $num <= 1 ) )
     {
-        $self->_message( 4, "Algorithm is 'auto', and integer is between -1 and 1, checking if we can find relative words." );
         LOCALE: foreach my $loc ( @$tree )
         {
             foreach my $this_style ( @styles )
             {
-                $self->_message( 4, "Checking if data can be found for locale '${loc}' for unit '${unit}', and style '${this_style}', and relative number '${num}'" );
                 my $ref = $cldr->date_field_l10n(
                     locale => $loc,
                     field_type => $unit,
                     field_length => $this_style,
                     relative => $num,
                 );
-                $self->_message( 4, "Method call to \$cldr->date_field_l10n returned: ", sub{ dump( $ref ) } );
                 return( $self->pass_error( $cldr->error ) ) if( !defined( $ref ) && $cldr->error );
                 if( $ref && scalar( keys( %$ref ) ) )
                 {
@@ -496,18 +460,14 @@ sub format_to_parts
     if( !defined( $pattern ) )
     {
         my $count = $cldr->plural_count( abs( $num ), $locale );
-        $self->_message( 4, "Count for number '${num}' and locale '${locale}' is '${count}'" );
         my $cldr_num = ( $num < 0 ? -1 : 1 );
         LOCALE: foreach my $loc ( @$tree )
         {
-            $self->_message( 4, "Checking locale '${locale}' -> '${loc}'" );
             foreach my $this_style ( @styles )
             {
-                $self->_message( 4, "\tChecking for style '${this_style}'" );
                 # As a safe fallback, we add 'other'
                 foreach my $cnt ( $count, ( $count ne 'other' ? ( 'other' ) : () ) )
                 {
-                    $self->_message( 4, "Trying to get the time relative pattern for count '${cnt}', field_type '${unit}', field_length '${this_style}', relative '${cldr_num}'" );
                     my $ref = $cldr->time_relative_l10n(
                         locale => $loc,
                         field_type => $unit,
@@ -516,7 +476,6 @@ sub format_to_parts
                         count => $cnt,
                     );
                     return( $self->pass_error( $cldr->error ) ) if( !defined( $ref ) && $cldr->error );
-                    $self->_message( 4, "\$cldr->time_relative_l10n() returned: ", sub{ dump( $ref ) } );
                     if( $ref && scalar( keys( %$ref ) ) )
                     {
                         $pattern = $ref->{format_pattern};
@@ -531,7 +490,6 @@ sub format_to_parts
         # foreach my $ns_type ( qw( native traditional finance ) )
     }
     return( $self->error( "No suitable pattern could be found. Something is wrong with the Locale::Unicode::Data database." ) ) if( !defined( $pattern ) );
-    $self->_message( 4, "Pattern found is '${pattern}'" );
 
     my $decimal;
     # If the number used has a decimal point, then we get the localised value of it.
@@ -551,7 +509,6 @@ sub format_to_parts
                 last LOCALE;
             }
         }
-        $self->_message( 4, "The user has provided a decimal number, and the decimal sign for the locale '${locale}' is '${decimal}'" );
     }
 
     my $parts = $self->_format_to_parts(
@@ -560,7 +517,6 @@ sub format_to_parts
         value => $num,
         ( defined( $decimal ) ? ( decimal => $decimal ) : () ),
     ) || return( $self->pass_error );
-    $self->_message( 4, "Parts are: ", sub{ dump( $parts ) } );
     return( $parts );
 }
 
@@ -600,7 +556,6 @@ sub supportedLocalesOf
         pop( @$tree );
         foreach my $loc ( @$tree )
         {
-            $self->_message( 4, "Checking if locale '", $loc, "' is supported in relative time." );
             my $all = $cldr->time_relatives_l10n(
                 locale => $loc,
             );
@@ -650,7 +605,6 @@ sub _format_to_parts
     {
         die( "Our numbering system digits are gone!" );
     }
-    $self->_message( 4, "Called for unit '${unit}' with value '${val}' and pattern '${pat}'" );
     my $opts = $self->resolvedOptions;
     my $num_sys = $opts->{numberingSystem};
 
@@ -665,9 +619,7 @@ sub _format_to_parts
         ]);
     }
 
-    $self->_message( 4, "Formatting for pattern '${pat}' and value '${val}'" );
     my @chunks = grep( length( $_ // '' ), split( /(\{0\})/, $pat ) );
-    $self->_message( 4, "Chunks contains: ", sub{ dump( \@chunks ) } );
     for my $i ( 0 .. $#chunks )
     {
         if( $chunks[$i] eq '{0}' )
@@ -675,7 +627,6 @@ sub _format_to_parts
             # $val could be an integer, or a decimal
             # if it is a decimal such as 3.5, then we need to create an hash entry for '3', '.' and '5'
             my( $int, $fraction ) = split( /\./, abs( $val ), 2 );
-            $self->_message( 4, "Value's integer part is '", ( $int // 'undef' ), "', and fraction part is '", ( $fraction // 'undef' ), "'" );
             push( @$parts, {
                 type => 'integer',
                 value => join( '', map( $digits->[ $_ ], split( //, $int ) ) ),
@@ -772,7 +723,6 @@ sub _greatest_interval
     my $quarter_diff  = ( $dt2->year - $dt1->year ) * 4 + ( $end_quarter - $start_quarter );
     $intervals{quarter} = $quarter_diff if( $quarter_diff > 0 );
     # $intervals{quarter} = abs( $quarter_diff ) if( $quarter_diff );
-    $self->_message( 4, "Interval found for d1 (", $dt1->iso8601, ") and d2 (", $dt2->iso8601, ") is: ", sub{ dump( \%intervals ) } );
 
     # Find the greatest interval unit by considering the hierarchy of units
     my @units_order = qw( year quarter month week day hour minute second );
@@ -1126,7 +1076,7 @@ For users requiring exact decimal representation beyond this precision, consider
 
 =head1 VERSION
 
-    v0.1.2
+    v0.1.3
 
 =head1 DESCRIPTION
 
